<?php 

namespace Quivers\Integration\Model;


use Magento\Payment\Model\CcGenericConfigProvider;
use Magento\Payment\Model\CcConfig;
use Stripe\Stripe;

/**
 * ConfigProvider Class
 */
class ConfigProvider extends CcGenericConfigProvider
{

	const CODE = 'quivers_integration';

    protected $scopeConfig;


	public function __construct(
	    CcConfig $ccConfig,
	    \Magento\Payment\Helper\Data $paymentHelper,
	    \Magento\Checkout\Model\Session $checkoutSession,
	    \Magento\Customer\Model\Session $customerSession,
	    \Magento\Payment\Model\Config $paymentConfig,
	    \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
	    array $methodCodes = []
	) {
	    // $this->paymentHelper    = $paymentHelper;
	    // $this->checkoutSession  = $checkoutSession;
	    // $this->customerSession  = $customerSession;
	    // $this->paymentConfig    = $paymentConfig;
	    $this->scopeConfig = $scopeConfig;

	    parent::__construct($ccConfig, $paymentHelper, [static::CODE]);
	}

	/**
	 * Get checkout config.
	 *
	 * @return array
	 */
	public function getConfig()
	{
		$storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        $publicKey = $this->scopeConfig->getValue('payment/quivers_stripe/public_key', $storeScope);
        $title = $this->scopeConfig->getValue('payment/quivers_stripe/title', $storeScope);
        $payPalTitle = $this->scopeConfig->getValue('payment/quivers_paypal/title', $storeScope);
        $payPalClientId = $this->scopeConfig->getValue('payment/quivers_paypal/client_id', $storeScope);
        $payPalSandbox = $this->scopeConfig->getValue('payment/quivers_paypal/quivers_paypal_sanndbox', $storeScope);

		// get current customer
		
		$methods = \Magento\Framework\App\ObjectManager::getInstance();
		$customerSession = $methods->get('Magento\Customer\Model\Session');

		$customer = $customerSession->getCustomer();
		$customerId = $customer->getId();
		$stripeCustomerId = $customer->getQuiversStripeCustomerId();
		$stripeCards = [];
		$selectedCard = [];
		if($stripeCustomerId) {
	        $stripeCustomer = \Stripe\Customer::retrieve($stripeCustomerId);
	        if($stripeCustomer) {
	        	if($stripeCustomer->id===$stripeCustomerId && $stripeCustomer->sources) {
	        		$cards = $stripeCustomer->sources->data;
	        		if(count($cards)>0) {
	        			foreach($cards as $card) {
	        				if(isset($card->card)) {
	        					$details = [
		        					'paymentSourceId'=>$card->id,
		        					'last4' => $card->card->last4,
		        					'expMonth' => $card->card->exp_month,
		        					'expYear' => $card->card->exp_year,
		        					'country' => $card->card->country,
		        					'cardType' => $card->card->funding,
		        					'label' => "XXXX-XXXX-XXXX-".$card->card->last4.' '.$card->card->exp_month.'/'.$card->card->exp_year,
		        				];
		        				$stripeCards[] = $details;
		        				if($card->id===$stripeCustomer->default_source) {
		        					$selectedCard = $details;
		        				}
	        				}
	        			}
	        		}
	        	}
	        }
		}
		$config = parent::getConfig();
		        $config = array_merge_recursive($config, [
            'payment' => [
                static::CODE => [
                    'publicKey' => $publicKey,
                    'title'=> $title,
                    'payPalTitle' => $payPalTitle,
                    'payPalClientId' => $payPalClientId,
                    'payPalSandbox' => $payPalSandbox,
                    'stripeCards' => $stripeCards,
                    'selectedCard' => $selectedCard,
                    'customerId' => $customerId
                ],
            ],
        ]);

        return $config;
	}

}