<?php

namespace Quivers\Integration\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer as EventObserver;
use Psr\Log\LoggerInterface as Logger;
use Magento\Framework\Exception\CouldNotSaveException;

class ConfigObserver implements ObserverInterface
{
    /**
     * @var Logger
     */
    protected $logger;

    protected $curlClient;
    protected $scopeConfig;

    /**
     * @param Logger $logger
     */
    
    const XML_MARKETPLACE_ID = 'quivers/parameters/marketplaceId';
    const XML_PRODUCTGROUP_ID = 'quivers/parameters/ProductGroupId';
    const XML_QUIVERS_API_KEY = 'quivers/parameters/quivers_api_key';
    const XML_QUIVERS_BUSINESS_REFID = 'quivers/parameters/merchant_ref_id';
    const XML_MAGENTO_ACCESS_TOKEN = 'quivers/parameters/magento_access_token';
    const XML_MAGENTO_BASE_URL = 'quivers/parameters/magento_base_url';
    const XML_QUIVERS_SANDBOX = 'quivers/parameters/quivers_sanndbox';


    protected $baseUrl = 'https://middleware.quiversdemo.com/profile';


    public function __construct(
        Logger $logger,
        \Magento\Framework\HTTP\Client\Curl $curl,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {
        $this->curlClient = $curl;
        $this->logger = $logger;
        $this->scopeConfig = $scopeConfig;
    }

    public function execute(EventObserver $observer)
    {
        $storeScope = \Magento\Store\Model\ScopeInterface::SCOPE_STORE;
        $marketPlaceId = $this->scopeConfig->getValue(self::XML_MARKETPLACE_ID, $storeScope);
        $productGroupId = $this->scopeConfig->getValue(self::XML_PRODUCTGROUP_ID, $storeScope);
        $quiversAPIKey = $this->scopeConfig->getValue(self::XML_QUIVERS_API_KEY, $storeScope);
        $magentoBaseUrl = $this->scopeConfig->getValue(self::XML_MAGENTO_BASE_URL, $storeScope);
        $quiversSandbox = $this->scopeConfig->getValue(self::XML_QUIVERS_SANDBOX, $storeScope);
        $quiversBusinessRefId = $this->scopeConfig->getValue(
            self::XML_QUIVERS_BUSINESS_REFID, $storeScope);
        $magentoAcessToken = $this->scopeConfig->getValue(
            self::XML_MAGENTO_ACCESS_TOKEN, $storeScope);

        if($quiversSandbox == 0) {
            $this->baseUrl = "https://middleware.quivers.com/profile";
        }

        $profileUrl = $this->baseUrl . "/create";
        $profileUpdateUrl = $this->baseUrl . "/update/marketplaces";

        $product_group_id_array = explode(", ", $productGroupId);
        $product_group_id_list = [];
        foreach ($product_group_id_array as $productGroupId) {
            array_push($product_group_id_list, $productGroupId);
        }

        $payload = [
            "client_type" => "Magento2",
            "base_url" => $magentoBaseUrl,
            "business_refid" => $quiversBusinessRefId,
            "api_key" => $quiversAPIKey,
            "auth_token" => "Bearer ".$magentoAcessToken
        ];
        $this->curlClient->addHeader("Content-Type", "application/json");
        $this->curlClient->post($profileUrl, json_encode($payload));

        $response = $this->curlClient->getBody();

        if($this->curlClient->getStatus()==200) {
            $response = json_decode($response, true);
            $uuid = $response["uuid"];
            $payload = [
                "marketplaces"=> [[
                    "marketplace_id"=> $marketPlaceId,
                    "currency"=> "USD",
                    "claiming_group_ids"=> $product_group_id_list
                ]]
            ];
            $this->curlClient->addHeader("uuid", $uuid);
            $this->curlClient->post($profileUpdateUrl, json_encode($payload));
            $response = $this->curlClient->getBody();

            if($this->curlClient->getStatus()!=200) {
                $errorMessage = 'An error occurred while updating the profile. ERROR: '.$response;
                throw new CouldNotSaveException(
                    __($errorMessage));
            }

        } else {
            $errorMessage = 'An error occurred while creating the profile. ERROR: '.$response;
            throw new CouldNotSaveException(
                __($errorMessage));
        }                
    }
}
